#[non_exhaustive]pub enum CpuSnapshotError {
Truncated {
expected: usize,
got: usize,
},
UnsupportedVersion(u8),
}Expand description
Errors returned by Cpu::restore.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Truncated
Blob length doesn’t match the schema for the version tag we read.
UnsupportedVersion(u8)
The blob’s version byte is not understood by this build.